<?php

namespace apexl\Io\modules\userDisplay\components;

use apexl\Io\modules\display\components\EntityDisplayTile;
use apexl\Io\modules\user\entities\userEntity;

readonly class userEntityDisplayTile extends EntityDisplayTile
{
    public function __construct($filters = '')
    {
        parent::__construct(new userEntity());
        $this->addContentTitle('Newest users', '', 5)
            ->addTable($filters, false, 'userEntity.data.summery')
            ->addButtonFooter([
                'userEntity.display.post' => 'Create',
                'userEntity.display.all' => 'View All',
            ]);
        $this->table->hideIdColumn();
    }
}
