<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\services;

use apexl\Io\modules\user\interfaces\UserPasswordHasherInterface;

final readonly class PasswordHashUserPasswordHasher implements UserPasswordHasherInterface
{
    public function hash(string $token): string
    {
        return password_hash($token, PASSWORD_DEFAULT);
    }
}